pub struct EventsBody { /* private fields */ }Trait Implementations
Sourceimpl Body for EventsBody
impl Body for EventsBody
Sourcetype Error = Infallible
type Error = Infallible
The error type this
Body might generate.Sourcefn poll_frame(
self: Pin<&mut Self>,
cx: &mut Context<'_>,
) -> Poll<Option<Result<Frame<Self::Data>, Self::Error>>>
fn poll_frame( self: Pin<&mut Self>, cx: &mut Context<'_>, ) -> Poll<Option<Result<Frame<Self::Data>, Self::Error>>>
Attempt to pull out the next data buffer of this stream.
Sourcefn is_end_stream(&self) -> bool
fn is_end_stream(&self) -> bool
Returns
true when the end of stream has been reached. Read moreSourceimpl IntoResponse for EventsBody
impl IntoResponse for EventsBody
Sourcefn into_response(self) -> Response
fn into_response(self) -> Response
Create a response.